@@ -288,6 +288,7 @@ class fMMS_SenderUI(hildon.Program):
 		
 		
 		to = self.eNumber.get_text()
+		# TODO: skip this if it looks like an email
 		if not self.cont.validate_phonenumber(to):
 			note = osso.SystemNote(self.osso_c)
 			note.system_note_dialog("Invalid phonenumber, must only contain + and digits" , 'notice')
@@ -315,24 +316,29 @@ class fMMS_SenderUI(hildon.Program):
 		sender = self.config.get_phonenumber()
 		tb = self.tvMessage.get_buffer()
 		message = tb.get_text(tb.get_start_iter(), tb.get_end_iter())
-		log.info("sender: %s attachment %s to %s message %s", sender, attachment, to, message)
+		log.info("sender: %s attachment: %s to: %s message: %s", sender, attachment, to, message)
 
 		""" Construct and send the message, off you go! """
-		# TODO: remove hardcoded subject
 		# TODO: let controller do this
 		try:
 			subject = message[:10]
 			if len(message) > 10:
 				subject += "..."
+			if len(subject) == 0:
+				subject = "MMS"
 			sender = MMSSender(to, subject, message, attachment, sender)
-			(status, reason, output) = sender.sendMMS()
+			(status, reason, output, parsed) = sender.sendMMS()
 			### TODO: Clean up and make this look decent
+			
+			if parsed == True and "Response-Status" in output:
+				if output['Response-Status'] == "Ok":
+					log.info("message seems to have sent AOK!")
+					banner = hildon.hildon_banner_show_information(self.spawner, "", "Message sent")
+					self.window.destroy()
+					return
+			
 			message = str(status) + "_" + str(reason)
-		
 			reply = str(output)
-			#print message
-			#note = osso.SystemNote(self.osso_c)
-			#ret = note.system_note_dialog("MMSC REPLIED:" + message + "\nBODY:" + reply, 'notice')
 			banner = hildon.hildon_banner_show_information(self.window, "", "MMSC REPLIED:" + message + "\nBODY: " + reply)
                         
 		except TypeError, exc:
